==> gail-0.4.tar.bz2: gail-0.4/gail/gailcanvaswidgetfactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>
#include <libgnomecanvas/gnome-canvas.h>
#include <libgnomecanvas/gnome-canvas-widget.h>
#include "gailcanvasitem.h"
#include "gailcanvaswidgetfactory.h"

static void
gail_canvas_widget_factory_class_init (GailCanvasWidgetFactoryClass *klass);

static AtkObject *
gail_canvas_widget_factory_create_accessible (GObject *obj);

static AtkObjectFactoryClass    *parent_class = NULL;

GType
gail_canvas_widget_factory_get_type ()
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailCanvasWidgetFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_canvas_widget_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailCanvasWidgetFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value table */
    };
    type = g_type_register_static (
                           ATK_TYPE_OBJECT_FACTORY, 
                           "GailCanvasWidgetFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_canvas_widget_factory_class_init (GailCanvasWidgetFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);

  class->create_accessible = gail_canvas_widget_factory_create_accessible;
}


AtkObjectFactory* 
gail_canvas_widget_factory_new ()
{
  GObject *factory;

  factory = g_object_new (GAIL_TYPE_CANVAS_WIDGET_FACTORY, NULL);

  g_return_val_if_fail (factory != NULL, NULL);
  return ATK_OBJECT_FACTORY (factory);
} 

static AtkObject* 
gail_canvas_widget_factory_create_accessible (GObject   *obj)
{
  AtkObject *accessible;
  GnomeCanvasWidget *widget;
  GnomeCanvasItem *item;

  g_return_val_if_fail (GNOME_IS_CANVAS_WIDGET (obj), NULL);
  widget = GNOME_CANVAS_WIDGET (obj);
  item = GNOME_CANVAS_ITEM (obj);
  g_return_val_if_fail (widget->widget, NULL);
  accessible = gtk_widget_get_accessible (widget->widget);
  g_return_val_if_fail (accessible != NULL, NULL);

  /* Reparent the accessible */
  if (item->parent)
    atk_object_set_parent (accessible, gail_canvas_item_get_accessible (item->parent));
  else
    atk_object_set_parent (accessible,
			   gtk_widget_get_accessible (GTK_WIDGET (item->canvas)));
  return accessible;
}

==> gail-0.8.tar.bz2: gail-0.8/gail/gailcanvaswidgetfactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "gailcanvaswidgetfactory.h"
#include "gailcanvaswidget.h"

static void gail_canvas_widget_factory_class_init (GailCanvasWidgetFactoryClass *klass);

static AtkObject * gail_canvas_widget_factory_create_accessible (GObject *obj);

static GType gail_canvas_widget_factory_get_accessible_type (void);

GType
gail_canvas_widget_factory_get_type ()
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailCanvasWidgetFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_canvas_widget_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailCanvasWidgetFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value table */
    };
    type = g_type_register_static (
                           ATK_TYPE_OBJECT_FACTORY, 
                           "GailCanvasWidgetFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_canvas_widget_factory_class_init (GailCanvasWidgetFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  class->create_accessible = gail_canvas_widget_factory_create_accessible;
  class->get_accessible_type = gail_canvas_widget_factory_get_accessible_type;
}

AtkObjectFactory* 
gail_canvas_widget_factory_new ()
{
  GObject *factory;

  factory = g_object_new (GAIL_TYPE_CANVAS_WIDGET_FACTORY, NULL);

  g_return_val_if_fail (factory != NULL, NULL);
  return ATK_OBJECT_FACTORY (factory);
} 

static AtkObject* 
gail_canvas_widget_factory_create_accessible (GObject   *obj)
{
  return gail_canvas_widget_new (obj);
}

static GType
gail_canvas_widget_factory_get_accessible_type (void)
{
  return GAIL_TYPE_CANVAS_WIDGET;
}
